Learn R Programming

animint2 (version 2023.6.11)

colsNotToCopy: Filter out columns that do not need to be copied

Description

Filter out columns that do not need to be copied

Usage

colsNotToCopy(g, s.aes)

Value

Character vector of columns not to be copied

Arguments

g

Geom with columns

s.aes

Selector aesthetics